/*

  Shoutcast-Macro

  Goes to the shoutcast favorites, starts the first favorite and exits.
  Macro A starts it almost immediately (intended for AutoStart because it waits until start process is finished and network is available).
  Macro B does it only if Blue/F4 is pressed.
  But it cannot be started a second time because the menu remembers the last chosen menu positions.
  In macro A the TAP reduces the volume (of analog audio output) to 0 until Shoutcast is started (so that you should not hear the sound of a TV channel.

  This TAP is for TMS only.


  Keys:
        Blue (F4)   starts the macro (only in macro B)

  Changes:
            15.08.2010  xyzzyx       support for TAPtoDate
            18.11.2010  xyzzyx       added FireBirdLib & KeyTranslate

  xyzzyx


*/

#include "tap.h"
#include "libFireBird.h"   //xyzzyx 101118, tested with FireBirdLib version "2010-11-14"

#define PGM_NAME "Shoutcast Macro"
#define PGM_VERS "V1.0b"
#define PGM_FULL PGM_NAME " " PGM_VERS

TAP_ID           ( 0x81AFFE13 );
TAP_PROGRAM_NAME (PGM_FULL);     //xyzzyx 100815 changed
TAP_PROGRAM_VERSION(PGM_VERS);   //xyzzyx 100815
TAP_AUTHOR_NAME  ("xyzzyx");
#ifdef _A
TAP_DESCRIPTION  ("Goes to shoutcast favorites almost immediately");
#endif
#ifdef _B
TAP_DESCRIPTION  ("Goes to shoutcast favorites by pressing F4");
#endif
TAP_ETCINFO      (__DATE__);

// Macros
#ifndef RKEY_Red
#define RKEY_Red RKEY_NewF1
#endif
#ifndef RKEY_White
#define RKEY_White 0x10049
#endif

#define SAFE_MEMFREE(p) { if(p){TAP_MemFree(p); p=NULL;} }


// Variables
dword last_key = 0;          // last pressed key to process
dword starttick;             // tick of TAP-start
int   volume;                // volume

// Prototypes
dword TAP_EventHandler (word event, dword param1, dword param2); // handles key events
int TAP_Main (void);         // the start function of this tap


// Functions
// handles key events
dword TAP_EventHandler (word event, dword param1, dword param2)
{
  (void) param2;

  // is there a key pressed?
  if (event == EVT_KEY)
  {
#ifdef _B
    if (param1 == RKEY_F4)
    {
      last_key = param1;
      param1 = 0;
    }
#endif
  }

  // time to do our work
  if (event == EVT_IDLE)
  {
#ifdef _A
    if (TAP_DiffTick(starttick, TAP_GetTick()) >= 750)
#endif
#ifdef _B
    if (last_key == RKEY_F4)
#endif
    {
      TAP_GenerateEvent (EVT_KEY, RKEY_Menu, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Right, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Ok, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Down, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Down, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Down, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Down, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Down, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Down, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Ok, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_F2, 0);
      TAP_GenerateEvent (EVT_KEY, RKEY_Ok, 0);
#ifdef _A
      TAP_SetSystemVar(SYSVAR_Vol, volume);
      TAP_WriteSystemVar();
#endif
      TAP_Exit();
    }
    last_key = 0;                                           // delete key
  }

  return param1;
}


int TAP_Main (void)
{
	KeyTranslate(TRUE, &TAP_EventHandler); //xyzzyx 101118
#ifdef _A
  starttick = TAP_GetTick();
  volume = TAP_GetSystemVar(SYSVAR_Vol);
  TAP_SetSystemVar(SYSVAR_Vol, 0);
  TAP_WriteSystemVar();
#endif
  return 1;
}
